EXPORTS
	?BufferToBeEmptiedData@RMMFDevSoundProxy@@QAEHAAV?$TPckgBuf@VTMMFDevSoundProxyHwBuf@@@@@Z @ 1 NONAME ; int RMMFDevSoundProxy::BufferToBeEmptiedData(class TPckgBuf<class TMMFDevSoundProxyHwBuf> &)
	?BufferToBeFilledData@RMMFDevSoundProxy@@QAEHAAV?$TPckgBuf@VTMMFDevSoundProxyHwBuf@@@@@Z @ 2 NONAME ; int RMMFDevSoundProxy::BufferToBeFilledData(class TPckgBuf<class TMMFDevSoundProxyHwBuf> &)
	?CancelRegisterAsClient@RMMFDevSoundProxy@@QAEHVTUid@@@Z @ 3 NONAME ; int RMMFDevSoundProxy::CancelRegisterAsClient(class TUid)
	?Capabilities@RMMFDevSoundProxy@@QAE?AVTMMFCapabilities@@XZ @ 4 NONAME ; class TMMFCapabilities RMMFDevSoundProxy::Capabilities(void)
	?Close@RMMFDevSoundProxy@@QAEXXZ @ 5 NONAME ; void RMMFDevSoundProxy::Close(void)
	?Config@RMMFDevSoundProxy@@QAE?AVTMMFCapabilities@@XZ @ 6 NONAME ; class TMMFCapabilities RMMFDevSoundProxy::Config(void)
	?CustomInterface@RMMFDevSoundProxy@@QAEPAXVTUid@@@Z @ 7 NONAME ; void * RMMFDevSoundProxy::CustomInterface(class TUid)
	?FixedSequenceCount@RMMFDevSoundProxy@@QAEHXZ @ 8 NONAME ; int RMMFDevSoundProxy::FixedSequenceCount(void)
	?FixedSequenceName@RMMFDevSoundProxy@@QAEABVTDesC16@@H@Z @ 9 NONAME ; class TDesC16 const & RMMFDevSoundProxy::FixedSequenceName(int)
	?Gain@RMMFDevSoundProxy@@QAEHXZ @ 10 NONAME ; int RMMFDevSoundProxy::Gain(void)
	?GetPlayBalanceL@RMMFDevSoundProxy@@QAEXAAH0@Z @ 11 NONAME ; void RMMFDevSoundProxy::GetPlayBalanceL(int &, int &)
	?GetRecordBalanceL@RMMFDevSoundProxy@@QAEXAAH0@Z @ 12 NONAME ; void RMMFDevSoundProxy::GetRecordBalanceL(int &, int &)
	?GetRecordedBufferL@RMMFDevSoundProxy@@QAEHAAVCMMFDataBuffer@@@Z @ 13 NONAME ; int RMMFDevSoundProxy::GetRecordedBufferL(class CMMFDataBuffer &)
	?GetResourceNotificationData@RMMFDevSoundProxy@@QAEHVTUid@@AAVTDes8@@@Z @ 14 NONAME ; int RMMFDevSoundProxy::GetResourceNotificationData(class TUid, class TDes8 &)
	?GetSupportedInputDataTypesL@RMMFDevSoundProxy@@QAEXAAV?$RArray@VTFourCC@@@@ABVTMMFPrioritySettings@@@Z @ 15 NONAME ; void RMMFDevSoundProxy::GetSupportedInputDataTypesL(class RArray<class TFourCC> &, class TMMFPrioritySettings const &)
	?GetSupportedOutputDataTypesL@RMMFDevSoundProxy@@QAEXAAV?$RArray@VTFourCC@@@@ABVTMMFPrioritySettings@@@Z @ 16 NONAME ; void RMMFDevSoundProxy::GetSupportedOutputDataTypesL(class RArray<class TFourCC> &, class TMMFPrioritySettings const &)
	?InitializeL@RMMFDevSoundProxy@@QAEHVTFourCC@@W4TMMFState@@@Z @ 17 NONAME ; int RMMFDevSoundProxy::InitializeL(class TFourCC, enum TMMFState)
	?InitializeL@RMMFDevSoundProxy@@QAEHVTUid@@W4TMMFState@@@Z @ 18 NONAME ; int RMMFDevSoundProxy::InitializeL(class TUid, enum TMMFState)
	?InitializeL@RMMFDevSoundProxy@@QAEHW4TMMFState@@@Z @ 19 NONAME ; int RMMFDevSoundProxy::InitializeL(enum TMMFState)
	?MaxGain@RMMFDevSoundProxy@@QAEHXZ @ 20 NONAME ; int RMMFDevSoundProxy::MaxGain(void)
	?MaxVolume@RMMFDevSoundProxy@@QAEHXZ @ 21 NONAME ; int RMMFDevSoundProxy::MaxVolume(void)
	?Open@RMMFDevSoundProxy@@QAEHAAVRHandleBase@@@Z @ 22 NONAME ; int RMMFDevSoundProxy::Open(class RHandleBase &)
	?Pause@RMMFDevSoundProxy@@QAEXXZ @ 23 NONAME ; void RMMFDevSoundProxy::Pause(void)
	?PlayDTMFStringL@RMMFDevSoundProxy@@QAEXABVTDesC16@@@Z @ 24 NONAME ; void RMMFDevSoundProxy::PlayDTMFStringL(class TDesC16 const &)
	?PlayData@RMMFDevSoundProxy@@QAEXXZ @ 25 NONAME ; void RMMFDevSoundProxy::PlayData(void)
	?PlayDualToneL@RMMFDevSoundProxy@@QAEXHHABVTTimeIntervalMicroSeconds@@@Z @ 26 NONAME ; void RMMFDevSoundProxy::PlayDualToneL(int, int, class TTimeIntervalMicroSeconds const &)
	?PlayFixedSequenceL@RMMFDevSoundProxy@@QAEXH@Z @ 27 NONAME ; void RMMFDevSoundProxy::PlayFixedSequenceL(int)
	?PlayInitL@RMMFDevSoundProxy@@QAEXXZ @ 28 NONAME ; void RMMFDevSoundProxy::PlayInitL(void)
	?PlayToneL@RMMFDevSoundProxy@@QAEXHABVTTimeIntervalMicroSeconds@@@Z @ 29 NONAME ; void RMMFDevSoundProxy::PlayToneL(int, class TTimeIntervalMicroSeconds const &)
	?PlayToneSequenceL@RMMFDevSoundProxy@@QAEXABVTDesC8@@@Z @ 30 NONAME ; void RMMFDevSoundProxy::PlayToneSequenceL(class TDesC8 const &)
	?RecordData@RMMFDevSoundProxy@@QAEXXZ @ 31 NONAME ; void RMMFDevSoundProxy::RecordData(void)
	?RecordInitL@RMMFDevSoundProxy@@QAEXXZ @ 32 NONAME ; void RMMFDevSoundProxy::RecordInitL(void)
	?RegisterAsClient@RMMFDevSoundProxy@@QAEHVTUid@@ABVTDesC8@@@Z @ 33 NONAME ; int RMMFDevSoundProxy::RegisterAsClient(class TUid, class TDesC8 const &)
	?SamplesPlayed@RMMFDevSoundProxy@@QAEHXZ @ 34 NONAME ; int RMMFDevSoundProxy::SamplesPlayed(void)
	?SamplesRecorded@RMMFDevSoundProxy@@QAEHXZ @ 35 NONAME ; int RMMFDevSoundProxy::SamplesRecorded(void)
	?SetBuffer@RMMFDevSoundProxy@@QAEXPAVCMMFDataBuffer@@@Z @ 36 NONAME ; void RMMFDevSoundProxy::SetBuffer(class CMMFDataBuffer *)
	?SetConfigL@RMMFDevSoundProxy@@QAEHABVTMMFCapabilities@@@Z @ 37 NONAME ; int RMMFDevSoundProxy::SetConfigL(class TMMFCapabilities const &)
	?SetDTMFLengths@RMMFDevSoundProxy@@QAEXAAVTTimeIntervalMicroSeconds32@@00@Z @ 38 NONAME ; void RMMFDevSoundProxy::SetDTMFLengths(class TTimeIntervalMicroSeconds32 &, class TTimeIntervalMicroSeconds32 &, class TTimeIntervalMicroSeconds32 &)
	?SetDevSoundInfo@RMMFDevSoundProxy@@QAEHXZ @ 39 NONAME ; int RMMFDevSoundProxy::SetDevSoundInfo(void)
	?SetGain@RMMFDevSoundProxy@@QAEHH@Z @ 40 NONAME ; int RMMFDevSoundProxy::SetGain(int)
	?SetPlayBalanceL@RMMFDevSoundProxy@@QAEXHH@Z @ 41 NONAME ; void RMMFDevSoundProxy::SetPlayBalanceL(int, int)
	?SetPrioritySettings@RMMFDevSoundProxy@@QAEXABVTMMFPrioritySettings@@@Z @ 42 NONAME ; void RMMFDevSoundProxy::SetPrioritySettings(class TMMFPrioritySettings const &)
	?SetRecordBalanceL@RMMFDevSoundProxy@@QAEXHH@Z @ 43 NONAME ; void RMMFDevSoundProxy::SetRecordBalanceL(int, int)
	?SetToneRepeats@RMMFDevSoundProxy@@QAEXHABVTTimeIntervalMicroSeconds@@@Z @ 44 NONAME ; void RMMFDevSoundProxy::SetToneRepeats(int, class TTimeIntervalMicroSeconds const &)
	?SetVolume@RMMFDevSoundProxy@@QAEHH@Z @ 45 NONAME ; int RMMFDevSoundProxy::SetVolume(int)
	?SetVolumeRamp@RMMFDevSoundProxy@@QAEXABVTTimeIntervalMicroSeconds@@@Z @ 46 NONAME ; void RMMFDevSoundProxy::SetVolumeRamp(class TTimeIntervalMicroSeconds const &)
	?Stop@RMMFDevSoundProxy@@QAEXXZ @ 47 NONAME ; void RMMFDevSoundProxy::Stop(void)
	?Volume@RMMFDevSoundProxy@@QAEHXZ @ 48 NONAME ; int RMMFDevSoundProxy::Volume(void)
	?WillResumePlay@RMMFDevSoundProxy@@QAEHXZ @ 49 NONAME ; int RMMFDevSoundProxy::WillResumePlay(void)
	?AsyncCustomCommand@RMMFDevSoundProxy@@QAEXVTUid@@AAVTRequestStatus@@ABVTDesC8@@2PAVTDes8@@@Z @ 50 NONAME ; void RMMFDevSoundProxy::AsyncCustomCommand(class TUid, class TRequestStatus &, class TDesC8 const &, class TDesC8 const &, class TDes8 *)
	?SyncCustomCommand@RMMFDevSoundProxy@@QAEHVTUid@@ABVTDesC8@@1PAVTDes8@@@Z @ 51 NONAME ; int RMMFDevSoundProxy::SyncCustomCommand(class TUid, class TDesC8 const &, class TDesC8 const &, class TDes8 *)
	?EmptyBuffers@RMMFDevSoundProxy@@QAEHXZ @ 52 NONAME ; int RMMFDevSoundProxy::EmptyBuffers(void)
	??0RMMFDevSoundProxy@@QAE@XZ @ 53 NONAME ; RMMFDevSoundProxy::RMMFDevSoundProxy(void)
	?SetClientThreadInfo@RMMFDevSoundProxy@@QAEHAAVTThreadId@@@Z @ 54 NONAME ; int RMMFDevSoundProxy::SetClientThreadInfo(class TThreadId &)
	?GetTimePlayed@RMMFDevSoundProxy@@QAEHAAVTTimeIntervalMicroSeconds@@@Z @ 55 NONAME ; int RMMFDevSoundProxy::GetTimePlayed(class TTimeIntervalMicroSeconds &)

